=======
History
=======

0.4.2 (2020-03-26)
------------------

* added parameter 'vswir_overlap_algorithm'


0.4.1 (2020-03-26)
------------------

* nosetests are now properly working:
  EnPT is called with the given GUI parameters and sends back a file containing all received parameters
  -> fixes issue #13 (closed)
* fixed Linux implementation
* improved error messages in case not all software components are properly installed


0.4.0 (2020-03-25)
------------------

* EnPT can now be interrupted by pressing the cancel button.
* Replaced placeholder app with a link to start the GUI.
* Added an About-Dialog.
* The package is now publicly available.
* Added PyPI upload.


0.3.0 (2020-01-28)
------------------

* The EnPT output is now properly displayed in the log window during EnPT runtime
* Code improvements
* Some minor documentation improvements


0.2.0 (2020-01-17)
------------------

* The GUI app is now working together with the EnPT backend installed in a separate Anaconda environment.
* Many improvements.
* Added documentation.



0.1.0 (2018-07-05)
------------------

* First release on GitLab.
